@@ -25,13 +25,20 @@ export MESONPY_EDITABLE_VERBOSE=1
 mkdir -p "${CCACHE_DIR}"
 mkdir -p "${COV_DIR}"
 
+python -m venv /tmp/venv
+source /tmp/venv/bin/activate
+
+# XXX: meson tries to use this for some reason, but it's not there by default
+mkdir -p /tmp/venv/include/pypy3.9
+
+python -m pip install --upgrade pip
 python -m pip install flake8 meson meson-python pycairo
 
 # CODE QUALITY
 python -m flake8
 
 # BUILD & TEST
-python -m pip install --no-build-isolation --editable '.[dev]'
+python -m pip install --config-settings=setup-args="-Dtests=true" --no-build-isolation --editable '.[dev]'
 
 lcov --config-file .gitlab-ci/lcovrc --directory . --capture --initial --output-file \
     "${COV_DIR}/${CI_JOB_NAME}-baseline.lcov"
